@@ -388,6 +388,50 @@ const struct s2n_signature_scheme* const s2n_sig_scheme_pref_list_20200207[] = {
     &s2n_ecdsa_sha1,
 };
 
+/* Same as above, but without sha1 */
+const struct s2n_signature_scheme* const s2n_sig_scheme_pref_list_20200207_no_sha1[] = {
+    /* RSA PSS */
+    &s2n_rsa_pss_pss_sha256,
+    &s2n_rsa_pss_pss_sha384,
+    &s2n_rsa_pss_pss_sha512,
+    &s2n_rsa_pss_rsae_sha256,
+    &s2n_rsa_pss_rsae_sha384,
+    &s2n_rsa_pss_rsae_sha512,
+
+    /* RSA PKCS1 */
+    &s2n_rsa_pkcs1_sha256,
+    &s2n_rsa_pkcs1_sha384,
+    &s2n_rsa_pkcs1_sha512,
+    &s2n_rsa_pkcs1_sha224,
+
+    /* ECDSA */
+    &s2n_ecdsa_sha256,
+    &s2n_ecdsa_sha384,
+    &s2n_ecdsa_sha512,
+    &s2n_ecdsa_sha224,
+};
+
+/* Same as above, but without sha224 */
+const struct s2n_signature_scheme* const s2n_sig_scheme_pref_list_20250813[] = {
+    /* RSA PSS */
+    &s2n_rsa_pss_pss_sha256,
+    &s2n_rsa_pss_pss_sha384,
+    &s2n_rsa_pss_pss_sha512,
+    &s2n_rsa_pss_rsae_sha256,
+    &s2n_rsa_pss_rsae_sha384,
+    &s2n_rsa_pss_rsae_sha512,
+
+    /* RSA PKCS1 */
+    &s2n_rsa_pkcs1_sha256,
+    &s2n_rsa_pkcs1_sha384,
+    &s2n_rsa_pkcs1_sha512,
+
+    /* ECDSA */
+    &s2n_ecdsa_sha256,
+    &s2n_ecdsa_sha384,
+    &s2n_ecdsa_sha512,
+};
+
 /*
  * These signature schemes were chosen based on the following specification:
  * https://nvlpubs.nist.gov/nistpubs/SpecialPublications/NIST.SP.800-52r2.pdf
@@ -476,6 +520,16 @@ const struct s2n_signature_preferences s2n_signature_preferences_20200207 = {
     .signature_schemes = s2n_sig_scheme_pref_list_20200207,
 };
 
+const struct s2n_signature_preferences s2n_signature_preferences_20200207_no_sha1 = {
+    .count = s2n_array_len(s2n_sig_scheme_pref_list_20200207_no_sha1),
+    .signature_schemes = s2n_sig_scheme_pref_list_20200207_no_sha1,
+};
+
+const struct s2n_signature_preferences s2n_signature_preferences_20250813 = {
+    .count = s2n_array_len(s2n_sig_scheme_pref_list_20250813),
+    .signature_schemes = s2n_sig_scheme_pref_list_20250813,
+};
+
 const struct s2n_signature_preferences s2n_signature_preferences_20201021 = {
     .count = s2n_array_len(s2n_sig_scheme_pref_list_20201021),
     .signature_schemes = s2n_sig_scheme_pref_list_20201021,
